pub struct KmeansFlags(/* private fields */);Expand description
k-means flags
Implementations
Sourceimpl KmeansFlags
impl KmeansFlags
Sourcepub const KMEANS_RANDOM_CENTERS: Self
pub const KMEANS_RANDOM_CENTERS: Self
Select random initial centers in each attempt.
Sourcepub const KMEANS_PP_CENTERS: Self
pub const KMEANS_PP_CENTERS: Self
Use kmeans++ center initialization by Arthur and Vassilvitskii [Arthur2007].
Sourcepub const KMEANS_USE_INITIAL_LABELS: Self
pub const KMEANS_USE_INITIAL_LABELS: Self
During the first (and possibly the only) attempt, use the user-supplied labels instead of computing them from the initial centers. For the second and further attempts, use the random or semi-random centers. Use one of KMEANS_*_CENTERS flag to specify the exact method.