pub struct SliceLayer { /* private fields */ }Expand description
Slice layer has several modes:
- Caffe mode
Parameters
- axis: Axis of split operation
- slice_point: Array of split points
Number of output blobs equals to number of split points plus one. The first blob is a slice on input from 0 to @p slice_point[0] - 1 by @p axis, the second output blob is a slice of input from @p slice_point[0] to @p slice_point[1] - 1 by @p axis and the last output blob is a slice of input from @p slice_point[-1] up to the end of @p axis size.
- TensorFlow mode
- begin: Vector of start indices
- size: Vector of sizes
More convenient numpy-like slice. One and only output blob
is a slice input[begin[0]:begin[0]+size[0], begin[1]:begin[1]+size[1], ...]
- Torch mode
- axis: Axis of split operation
Split input blob on the equal parts by @p axis.
Implementations
Sourceimpl SliceLayer
impl SliceLayer
Sourcepub fn default() -> SliceLayer
pub fn default() -> SliceLayer
Creates a default instance of the class by calling the default constructor
pub fn create(params: &impl LayerParamsTraitConst) -> Result<Ptr<SliceLayer>>