Module features2d

Module features2d 

Features Framework

Feature Detection and Description

Descriptor Matchers

Matchers of keypoint descriptors in OpenCV have wrappers with a common interface that enables you to easily switch between different algorithms solving the same problem. This section is devoted to matching descriptors that are represented as vectors in a multidimensional space. All objects that implement vector descriptor matchers inherit the DescriptorMatcher interface.

Drawing Function of Keypoints and Matches

Hardware Acceleration Layer

Approximate Nearest Neighbors Search in Multi-Dimensional Spaces

This section documents OpenCV’s interface to the Annoy. Annoy (Approximate Nearest Neighbors Oh Yeah) is a library to search for points in space that are close to a given query point. It also creates large read-only file-based data structures that are mmapped into memory so that many processes may share the same data.

Modules

prelude

Structs

ALIKED
ALIKED feature detector and descriptor extractor.
ALIKED_Params
ANNIndex
AffineFeature
Class for implementing the wrapper which makes detectors and extractors to be affine invariant, described as ASIFT in YM11 .
BFMatcher
Brute-force descriptor matcher.
DISK
DISK feature detector and descriptor, based on a DNN model.
DescriptorMatcher
Abstract base class for matching keypoint descriptors.
DrawMatchesFlags
FastFeatureDetector
Wrapping class for feature detection using the FAST method.
Feature2D
Abstract base class for 2D image feature detectors and descriptor extractors
FlannBasedMatcher
Flann-based descriptor matcher.
GFTTDetector
Wrapping class for feature detection using the goodFeaturesToTrack function. :
KeyPointsFilter
A class filters a vector of keypoints.
LightGlueMatcher
LightGlue feature matcher.
MSER
Maximally stable extremal region extractor
ORB
Class implementing the ORB (oriented BRIEF) keypoint detector and descriptor extractor
SIFT
Class for extracting keypoints and computing descriptors using the Scale Invariant Feature Transform (SIFT) algorithm by D. Lowe Lowe04 .
SimpleBlobDetector
Class for extracting blobs from an image. :
SimpleBlobDetector_Params

Enums

ANNIndex_Distance
Metrics used to calculate the distance between two feature vectors.
DescriptorMatcher_MatcherType
FastFeatureDetector_DetectorType
ORB_ScoreType

Constants

ANNIndex_DIST_ANGULAR
ANNIndex_DIST_DOTPRODUCT
ANNIndex_DIST_EUCLIDEAN
ANNIndex_DIST_HAMMING
ANNIndex_DIST_MANHATTAN
DescriptorMatcher_BRUTEFORCE
DescriptorMatcher_BRUTEFORCE_HAMMING
DescriptorMatcher_BRUTEFORCE_HAMMINGLUT
DescriptorMatcher_BRUTEFORCE_L1
DescriptorMatcher_BRUTEFORCE_SL2
DescriptorMatcher_FLANNBASED
DrawMatchesFlags_DEFAULT
Output image matrix will be created (Mat::create), i.e. existing memory of output image may be reused. Two source image, matches and single keypoints will be drawn. For each keypoint only the center point will be drawn (without the circle around keypoint with keypoint size and orientation).
DrawMatchesFlags_DRAW_OVER_OUTIMG
Output image matrix will not be created (Mat::create). Matches will be drawn on existing content of output image.
DrawMatchesFlags_DRAW_RICH_KEYPOINTS
For each keypoint the circle around keypoint with keypoint size and orientation will be drawn.
DrawMatchesFlags_NOT_DRAW_SINGLE_POINTS
Single keypoints will not be drawn.
FastFeatureDetector_FAST_N
FastFeatureDetector_NONMAX_SUPPRESSION
FastFeatureDetector_THRESHOLD
FastFeatureDetector_TYPE_5_8
FastFeatureDetector_TYPE_7_12
FastFeatureDetector_TYPE_9_16
ORB_FAST_SCORE
ORB_HARRIS_SCORE

Traits

ALIKEDTrait
Mutable methods for crate::features::ALIKED
ALIKEDTraitConst
Constant methods for crate::features::ALIKED
ANNIndexTrait
Mutable methods for crate::features::ANNIndex
ANNIndexTraitConst
Constant methods for crate::features::ANNIndex
AffineFeatureTrait
Mutable methods for crate::features::AffineFeature
AffineFeatureTraitConst
Constant methods for crate::features::AffineFeature
BFMatcherTrait
Mutable methods for crate::features::BFMatcher
BFMatcherTraitConst
Constant methods for crate::features::BFMatcher
DISKTrait
Mutable methods for crate::features::DISK
DISKTraitConst
Constant methods for crate::features::DISK
DescriptorMatcherTrait
Mutable methods for crate::features::DescriptorMatcher
DescriptorMatcherTraitConst
Constant methods for crate::features::DescriptorMatcher
FastFeatureDetectorTrait
Mutable methods for crate::features::FastFeatureDetector
FastFeatureDetectorTraitConst
Constant methods for crate::features::FastFeatureDetector
Feature2DTrait
Mutable methods for crate::features::Feature2D
Feature2DTraitConst
Constant methods for crate::features::Feature2D
FlannBasedMatcherTrait
Mutable methods for crate::features::FlannBasedMatcher
FlannBasedMatcherTraitConst
Constant methods for crate::features::FlannBasedMatcher
GFTTDetectorTrait
Mutable methods for crate::features::GFTTDetector
GFTTDetectorTraitConst
Constant methods for crate::features::GFTTDetector
KeyPointsFilterTrait
Mutable methods for crate::features::KeyPointsFilter
KeyPointsFilterTraitConst
Constant methods for crate::features::KeyPointsFilter
LightGlueMatcherTrait
Mutable methods for crate::features::LightGlueMatcher
LightGlueMatcherTraitConst
Constant methods for crate::features::LightGlueMatcher
MSERTrait
Mutable methods for crate::features::MSER
MSERTraitConst
Constant methods for crate::features::MSER
ORBTrait
Mutable methods for crate::features::ORB
ORBTraitConst
Constant methods for crate::features::ORB
SIFTTrait
Mutable methods for crate::features::SIFT
SIFTTraitConst
Constant methods for crate::features::SIFT
SimpleBlobDetectorTrait
Mutable methods for crate::features::SimpleBlobDetector
SimpleBlobDetectorTraitConst
Constant methods for crate::features::SimpleBlobDetector

Functions

compute_recall_precision_curve
draw_keypoints
Draws keypoints.
draw_keypoints_def
Draws keypoints.
draw_matches
Draws the found matches of keypoints from two images.
draw_matches_def
Draws the found matches of keypoints from two images.
draw_matches_knn
C++ default parameters
draw_matches_knn_def
Note
draw_matches_with_thickness
Draws the found matches of keypoints from two images.
draw_matches_with_thickness_def
Draws the found matches of keypoints from two images.
evaluate_feature_detector
C++ default parameters
evaluate_feature_detector_def
Note
fast_with_type
Detects corners using the FAST algorithm
fast_with_type_def
Detects corners using the FAST algorithm
get_nearest_point
get_recall
good_features_to_track
Determines strong corners on an image.
good_features_to_track_1
C++ default parameters
good_features_to_track_1_def
Note
good_features_to_track_def
Determines strong corners on an image.
good_features_to_track_with_quality
Same as above, but returns also quality measure of the detected corners.
good_features_to_track_with_quality_def
Same as above, but returns also quality measure of the detected corners.

Type Aliases

AffineDescriptorExtractor
AffineFeatureDetector
DescriptorExtractor
Extractors of keypoint descriptors in OpenCV have wrappers with a common interface that enables you to easily switch between different algorithms solving the same problem. This section is devoted to computing descriptors represented as vectors in a multidimensional space. All objects that implement the vector descriptor extractors inherit the DescriptorExtractor interface.
FeatureDetector
Feature detectors in OpenCV have wrappers with a common interface that enables you to easily switch between different algorithms solving the same problem. All objects that implement keypoint detectors inherit the FeatureDetector interface.
SiftDescriptorExtractor
SiftFeatureDetector