project_points_2

Function project_points_2 

pub fn project_points_2(
    object_points: &impl ToInputArray,
    image_points: &mut impl ToOutputArray,
    rvec: &impl ToInputArray,
    tvec: &impl ToInputArray,
    k: &impl ToInputArray,
    d: &impl ToInputArray,
    alpha: f64,
    jacobian: &mut impl ToOutputArray,
) -> Result<()>
Projects points using fisheye model

Parameters

  • objectPoints: Array of object points, 1xN/Nx1 3-channel (or vector<Point3f> ), where N is the number of points in the view.
  • imagePoints: Output array of image points, 2xN/Nx2 1-channel or 1xN/Nx1 2-channel, or vector<Point2f>.
  • affine:
  • K: Camera intrinsic matrix inline formula.
  • D: Input vector of distortion coefficients inline formula.
  • alpha: The skew coefficient.
  • jacobian: Optional output 2Nx15 jacobian matrix of derivatives of image points with respect to components of the focal lengths, coordinates of the principal point, distortion coefficients, rotation vector, translation vector, and the skew. In the old interface different components of the jacobian are returned via different output parameters.

The function computes projections of 3D points to the image plane given intrinsic and extrinsic camera parameters. Optionally, the function computes Jacobians - matrices of partial derivatives of image points coordinates (as functions of all the input parameters) with respect to the particular parameters, intrinsic and/or extrinsic.

Overloaded parameters

C++ default parameters

  • alpha: 0
  • jacobian: noArray()