triangulate_points

Function triangulate_points 

pub fn triangulate_points(
    proj_matr1: &impl ToInputArray,
    proj_matr2: &impl ToInputArray,
    proj_points1: &impl ToInputArray,
    proj_points2: &impl ToInputArray,
    points4_d: &mut impl ToOutputArray,
) -> Result<()>
This function reconstructs 3-dimensional points (in homogeneous coordinates) by using their observations with a stereo camera.

Parameters

  • projMatr1: 3x4 projection matrix of the first camera, i.e. this matrix projects 3D points given in the world’s coordinate system into the first image.
  • projMatr2: 3x4 projection matrix of the second camera, i.e. this matrix projects 3D points given in the world’s coordinate system into the second image.
  • projPoints1: 2xN array of feature points in the first image. In the case of the c++ version, it can be also a vector of feature points or two-channel matrix of size 1xN or Nx1.
  • projPoints2: 2xN array of corresponding points in the second image. In the case of the c++ version, it can be also a vector of feature points or two-channel matrix of size 1xN or Nx1.
  • points4D: 4xN array of reconstructed points in homogeneous coordinates. These points are returned in the world’s coordinate system.

Note: Keep in mind that all input data should be of float type in order for this function to work.

Note: If the projection matrices from [stereoRectify] are used, then the returned points are represented in the first camera’s rectified coordinate system.

See also

reprojectImageTo3D