RegionGrowing3DTraitConst

Trait RegionGrowing3DTraitConst 

pub trait RegionGrowing3DTraitConst {
    // Required method
    fn as_raw_RegionGrowing3D(&self) -> *const c_void;

    // Provided methods
    fn get_min_size(&self) -> Result<i32> { ... }
    fn get_max_size(&self) -> Result<i32> { ... }
    fn get_smooth_mode_flag(&self) -> Result<bool> { ... }
    fn get_smoothness_threshold(&self) -> Result<f64> { ... }
    fn get_curvature_threshold(&self) -> Result<f64> { ... }
    fn get_max_number_of_neighbors(&self) -> Result<i32> { ... }
    fn get_number_of_regions(&self) -> Result<i32> { ... }
    fn get_need_sort(&self) -> Result<bool> { ... }
    fn get_seeds(&self, seeds: &mut impl ToOutputArray) -> Result<()> { ... }
    fn get_curvatures(&self, curvatures: &mut impl ToOutputArray) -> Result<()> { ... }
}
Constant methods for crate::geometry::RegionGrowing3D

Required Methods

Provided Methods

fn get_min_size(&self) -> Result<i32>

Get the minimum size of region.

fn get_max_size(&self) -> Result<i32>

Get the maximum size of region.

fn get_smooth_mode_flag(&self) -> Result<bool>

Get whether to use the smoothness mode.

fn get_smoothness_threshold(&self) -> Result<f64>

Get threshold value of the angle between normals.

fn get_curvature_threshold(&self) -> Result<f64>

Get threshold value of curvature.

fn get_max_number_of_neighbors(&self) -> Result<i32>

Get the maximum number of neighbors including itself.

fn get_number_of_regions(&self) -> Result<i32>

Get the maximum number of regions you want.

fn get_need_sort(&self) -> Result<bool>

Get whether the results need to be sorted you have set.

fn get_seeds(&self, seeds: &mut impl ToOutputArray) -> Result<()>

Get the seed points.

fn get_curvatures(&self, curvatures: &mut impl ToOutputArray) -> Result<()>

Get the curvature of each point if you have set.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors