pub trait Detail_TrackerContribFeatureSetTrait: Detail_TrackerContribFeatureSetTraitConst {
// Required method
fn as_raw_mut_Detail_TrackerContribFeatureSet(&mut self) -> *mut c_void;
// Provided methods
fn extraction(&mut self, images: &Vector<Mat>) -> Result<()> { ... }
fn selection(&mut self) -> Result<()> { ... }
fn remove_outliers(&mut self) -> Result<()> { ... }
fn add_tracker_feature(
&mut self,
tracker_feature_type: &str,
) -> Result<bool> { ... }
fn add_tracker_feature_1(
&mut self,
feature: &mut Ptr<Detail_TrackerContribFeature>,
) -> Result<bool> { ... }
}Expand description
Mutable methods for crate::tracking::Detail_TrackerContribFeatureSet
Required Methods
fn as_raw_mut_Detail_TrackerContribFeatureSet(&mut self) -> *mut c_void
Provided Methods
Sourcefn selection(&mut self) -> Result<()>
fn selection(&mut self) -> Result<()>
Identify most effective features for all feature types (optional)
Sourcefn remove_outliers(&mut self) -> Result<()>
fn remove_outliers(&mut self) -> Result<()>
Remove outliers for all feature types (optional)
Sourcefn add_tracker_feature(&mut self, tracker_feature_type: &str) -> Result<bool>
fn add_tracker_feature(&mut self, tracker_feature_type: &str) -> Result<bool>
Add TrackerContribFeature in the collection. Return true if TrackerContribFeature is added, false otherwise
Parameters
- trackerFeatureType: The TrackerContribFeature name
The modes available now:
- “HAAR” – Haar Feature-based
The modes that will be available soon:
- “HOG” – Histogram of Oriented Gradients features
- “LBP” – Local Binary Pattern features
- “FEATURE2D” – All types of Feature2D
Example TrackerContribFeatureSet::addTrackerFeature : :
//sample usage:
Ptr<TrackerContribFeature> trackerFeature = ...;
featureSet->addTrackerFeature( trackerFeature );
//or add CSC sampler with default parameters
//featureSet->addTrackerFeature( "HAAR" );Note: If you use the second method, you must initialize the TrackerContribFeature
Sourcefn add_tracker_feature_1(
&mut self,
feature: &mut Ptr<Detail_TrackerContribFeature>,
) -> Result<bool>
fn add_tracker_feature_1( &mut self, feature: &mut Ptr<Detail_TrackerContribFeature>, ) -> Result<bool>
Add TrackerContribFeature in the collection. Return true if TrackerContribFeature is added, false otherwise
Parameters
- trackerFeatureType: The TrackerContribFeature name
The modes available now:
- “HAAR” – Haar Feature-based
The modes that will be available soon:
- “HOG” – Histogram of Oriented Gradients features
- “LBP” – Local Binary Pattern features
- “FEATURE2D” – All types of Feature2D
Example TrackerContribFeatureSet::addTrackerFeature : :
//sample usage:
Ptr<TrackerContribFeature> trackerFeature = ...;
featureSet->addTrackerFeature( trackerFeature );
//or add CSC sampler with default parameters
//featureSet->addTrackerFeature( "HAAR" );Note: If you use the second method, you must initialize the TrackerContribFeature
Overloaded parameters
- feature: The TrackerContribFeature class