pub struct ANN_MLP { /* private fields */ }Expand description
Artificial Neural Networks - Multi-Layer Perceptrons.
Unlike many other models in ML that are constructed and trained at once, in the MLP model these steps are separated. First, a network with the specified topology is created using the non-default constructor or the method ANN_MLP::create. All the weights are set to zeros. Then, the network is trained using a set of input and output vectors. The training procedure can be repeated more than once, that is, the weights can be adjusted based on the new training data.
Additional flags for StatModel::train are available: ANN_MLP::TrainFlags.
See also
[ml_intro_ann]
Implementations
Sourceimpl ANN_MLP
impl ANN_MLP
Sourcepub fn create() -> Result<Ptr<ANN_MLP>>
pub fn create() -> Result<Ptr<ANN_MLP>>
Creates empty model
Use StatModel::train to train the model, Algorithm::load<ANN_MLP>(filename) to load the pre-trained model. Note that the train method has optional flags: ANN_MLP::TrainFlags.
Sourcepub fn load(filepath: impl AsRef<OsStr>) -> Result<Ptr<ANN_MLP>>
pub fn load(filepath: impl AsRef<OsStr>) -> Result<Ptr<ANN_MLP>>
Loads and creates a serialized ANN from a file
Use ANN::save to serialize and store an ANN to disk. Load the ANN from this file again, by calling this function with the path to the file.
Parameters
- filepath: path to serialized ANN