KNearest

Struct KNearest 

pub struct KNearest { /* private fields */ }
The class implements K-Nearest Neighbors model

See also

[ml_intro_knn]

Implementations

Source

impl KNearest

pub fn create() -> Result<Ptr<KNearest>>

Creates the empty model

The static method creates empty %KNearest classifier. It should be then trained using StatModel::train method.

pub fn load(filepath: &str) -> Result<Ptr<KNearest>>

Loads and creates a serialized knearest from a file

Use KNearest::save to serialize and store an KNearest to disk. Load the KNearest from this file again, by calling this function with the path to the file.

Parameters
  • filepath: path to serialized KNearest