pub struct GridBoard { /* private fields */ }Expand description
Planar board with grid arrangement of markers
More common type of board. All markers are placed in the same plane in a grid arrangement. The board image can be drawn using generateImage() method.
Implementations
Sourceimpl GridBoard
impl GridBoard
Sourcepub fn new(
size: Size,
marker_length: f32,
marker_separation: f32,
dictionary: &impl DictionaryTraitConst,
ids: &impl ToInputArray,
) -> Result<GridBoard>
pub fn new( size: Size, marker_length: f32, marker_separation: f32, dictionary: &impl DictionaryTraitConst, ids: &impl ToInputArray, ) -> Result<GridBoard>
GridBoard constructor
Parameters
- size: number of markers in x and y directions
- markerLength: marker side length (normally in meters)
- markerSeparation: separation between two markers (same unit as markerLength)
- dictionary: dictionary of markers indicating the type of markers
- ids: set of marker ids in dictionary to use on board.
C++ default parameters
- ids: noArray()
Sourcepub fn new_def(
size: Size,
marker_length: f32,
marker_separation: f32,
dictionary: &impl DictionaryTraitConst,
) -> Result<GridBoard>
pub fn new_def( size: Size, marker_length: f32, marker_separation: f32, dictionary: &impl DictionaryTraitConst, ) -> Result<GridBoard>
GridBoard constructor
Parameters
- size: number of markers in x and y directions
- markerLength: marker side length (normally in meters)
- markerSeparation: separation between two markers (same unit as markerLength)
- dictionary: dictionary of markers indicating the type of markers
- ids: set of marker ids in dictionary to use on board.
Note
This alternative version of [new] function uses the following default values for its arguments:
- ids: noArray()
pub fn default() -> Result<GridBoard>