StitcherTraitConst

Trait StitcherTraitConst 

pub trait StitcherTraitConst {
Show 21 methods // Required method fn as_raw_Stitcher(&self) -> *const c_void; // Provided methods fn registration_resol(&self) -> Result<f64> { ... } fn seam_estimation_resol(&self) -> Result<f64> { ... } fn compositing_resol(&self) -> Result<f64> { ... } fn pano_confidence_thresh(&self) -> Result<f64> { ... } fn wave_correction(&self) -> Result<bool> { ... } fn interpolation_flags(&self) -> Result<InterpolationFlags> { ... } fn wave_correct_kind(&self) -> Result<Detail_WaveCorrectKind> { ... } fn features_finder(&self) -> Result<Ptr<Feature2D>> { ... } fn features_matcher(&self) -> Result<Ptr<Detail_FeaturesMatcher>> { ... } fn matching_mask(&self) -> Result<UMat> { ... } fn bundle_adjuster(&self) -> Result<Ptr<Detail_BundleAdjusterBase>> { ... } fn estimator(&self) -> Result<Ptr<Detail_Estimator>> { ... } fn warper(&self) -> Result<Ptr<WarperCreator>> { ... } fn exposure_compensator(&self) -> Result<Ptr<Detail_ExposureCompensator>> { ... } fn seam_finder(&self) -> Result<Ptr<Detail_SeamFinder>> { ... } fn blender(&self) -> Result<Ptr<Detail_Blender>> { ... } fn component(&self) -> Result<Vector<i32>> { ... } fn cameras(&self) -> Result<Vector<Detail_CameraParams>> { ... } fn work_scale(&self) -> Result<f64> { ... } fn result_mask(&self) -> Result<UMat> { ... }
}
Constant methods for crate::stitching::Stitcher

Required Methods

Provided Methods

fn registration_resol(&self) -> Result<f64>

fn seam_estimation_resol(&self) -> Result<f64>

fn compositing_resol(&self) -> Result<f64>

fn pano_confidence_thresh(&self) -> Result<f64>

fn wave_correction(&self) -> Result<bool>

fn interpolation_flags(&self) -> Result<InterpolationFlags>

fn wave_correct_kind(&self) -> Result<Detail_WaveCorrectKind>

fn features_finder(&self) -> Result<Ptr<Feature2D>>

fn features_matcher(&self) -> Result<Ptr<Detail_FeaturesMatcher>>

fn matching_mask(&self) -> Result<UMat>

fn bundle_adjuster(&self) -> Result<Ptr<Detail_BundleAdjusterBase>>

fn estimator(&self) -> Result<Ptr<Detail_Estimator>>

fn warper(&self) -> Result<Ptr<WarperCreator>>

fn exposure_compensator(&self) -> Result<Ptr<Detail_ExposureCompensator>>

fn seam_finder(&self) -> Result<Ptr<Detail_SeamFinder>>

fn blender(&self) -> Result<Ptr<Detail_Blender>>

fn component(&self) -> Result<Vector<i32>>

Returns indices of input images used in panorama stitching

fn cameras(&self) -> Result<Vector<Detail_CameraParams>>

Returns estimated camera parameters for all stitched images

fn work_scale(&self) -> Result<f64>

fn result_mask(&self) -> Result<UMat>

Return the mask of the panorama.

The mask is a 8U UMat with the values: 0xFF (white) for pixels filled by the input images, 0 (black) for unused pixels. It can be used as the mask for inpaint.

Returns

The mask.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors