VolumeParamsTraitConst

Trait VolumeParamsTraitConst 

pub trait VolumeParamsTraitConst {
Show 13 methods // Required method fn as_raw_VolumeParams(&self) -> *const c_void; // Provided methods fn kind(&self) -> VolumeType { ... } fn resolution_x(&self) -> i32 { ... } fn resolution_y(&self) -> i32 { ... } fn resolution_z(&self) -> i32 { ... } fn unit_resolution(&self) -> i32 { ... } fn volum_size(&self) -> f32 { ... } fn pose(&self) -> Matx44f { ... } fn voxel_size(&self) -> f32 { ... } fn tsdf_trunc_dist(&self) -> f32 { ... } fn max_weight(&self) -> i32 { ... } fn depth_trunc_threshold(&self) -> f32 { ... } fn raycast_step_factor(&self) -> f32 { ... }
}
Constant methods for crate::rgbd::VolumeParams

Required Methods

Provided Methods

fn kind(&self) -> VolumeType

Kind of Volume

Values can be TSDF (single volume) or HASHTSDF (hashtable of volume units)

fn resolution_x(&self) -> i32

Resolution of voxel space

Number of voxels in each dimension. Applicable only for TSDF Volume. HashTSDF volume only supports equal resolution in all three dimensions

fn resolution_y(&self) -> i32

fn resolution_z(&self) -> i32

fn unit_resolution(&self) -> i32

Resolution of volumeUnit in voxel space

Number of voxels in each dimension for volumeUnit Applicable only for hashTSDF.

fn volum_size(&self) -> f32

Size of volume in meters

fn pose(&self) -> Matx44f

Initial pose of the volume in meters, should be 4x4 float or double matrix

fn voxel_size(&self) -> f32

Length of voxels in meters

fn tsdf_trunc_dist(&self) -> f32

TSDF truncation distance

Distances greater than value from surface will be truncated to 1.0

fn max_weight(&self) -> i32

Max number of frames to integrate per voxel

Represents the max number of frames over which a running average of the TSDF is calculated for a voxel

fn depth_trunc_threshold(&self) -> f32

Threshold for depth truncation in meters

Truncates the depth greater than threshold to 0

fn raycast_step_factor(&self) -> f32

Length of single raycast step

Describes the percentage of voxel length that is skipped per march

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors