WCircle

Struct WCircle 

pub struct WCircle { /* private fields */ }
This 3D Widget defines a circle.

Implementations

Source

impl WCircle

pub fn new( radius: f64, thickness: f64, color: &impl ColorTraitConst, ) -> Result<WCircle>

Constructs default planar circle centered at origin with plane normal along z-axis

Parameters
  • radius: Radius of the circle.
  • thickness: Thickness of the circle.
  • color: Color of the circle.
C++ default parameters
  • thickness: 0.01
  • color: Color::white()
pub fn new_def(radius: f64) -> Result<WCircle>

Constructs default planar circle centered at origin with plane normal along z-axis

Parameters
  • radius: Radius of the circle.
  • thickness: Thickness of the circle.
  • color: Color of the circle.
Note

This alternative version of [new] function uses the following default values for its arguments:

  • thickness: 0.01
  • color: Color::white()
pub fn new_1( radius: f64, center: Point3d, normal: Vec3d, thickness: f64, color: &impl ColorTraitConst, ) -> Result<WCircle>

Constructs repositioned planar circle.

Parameters
  • radius: Radius of the circle.
  • center: Center of the circle.
  • normal: Normal of the plane in which the circle lies.
  • thickness: Thickness of the circle.
  • color: Color of the circle.
C++ default parameters
  • thickness: 0.01
  • color: Color::white()
pub fn new_def_1(radius: f64, center: Point3d, normal: Vec3d) -> Result<WCircle>

Constructs repositioned planar circle.

Parameters
  • radius: Radius of the circle.
  • center: Center of the circle.
  • normal: Normal of the plane in which the circle lies.
  • thickness: Thickness of the circle.
  • color: Color of the circle.
Note

This alternative version of [new] function uses the following default values for its arguments:

  • thickness: 0.01
  • color: Color::white()