Module xstereo

Module xstereo 

Extra Stereo Correspondance Algorithms

Modules

prelude

Structs

MatchQuasiDense
\addtogroup xstereo
PropagationParameters
QuasiDenseStereo
Class containing the methods needed for Quasi Dense Stereo computation.

Constants

CV_CS_CENSUS
CV_DENSE_CENSUS
CV_MEAN_VARIATION
CV_MODIFIED_CENSUS_TRANSFORM
CV_MODIFIED_CS_CENSUS
CV_QUADRATIC_INTERPOLATION
CV_SIMETRICV_INTERPOLATION
CV_SPARSE_CENSUS
CV_SPECKLE_REMOVAL_ALGORITHM
CV_SPECKLE_REMOVAL_AVG_ALGORITHM
CV_STAR_KERNEL

Traits

QuasiDenseStereoTrait
Mutable methods for crate::xstereo::QuasiDenseStereo
QuasiDenseStereoTraitConst
Constant methods for crate::xstereo::QuasiDenseStereo

Functions

census_transform
Two variations of census applied on input images Implementation of a census transform which is taking into account just the some pixels from the census kernel thus allowing for larger block sizes *
census_transform_1
single image census transform
modified_census_transform
STANDARD_MCT - Modified census which is memorizing for each pixel 2 bits and includes a tolerance to the pixel comparison MCT_MEAN_VARIATION - Implementation of a modified census transform which is also taking into account the variation to the mean of the window not just the center pixel *
modified_census_transform_1
single version of modified census transform descriptor
modified_census_transform_1_def
single version of modified census transform descriptor
modified_census_transform_def
STANDARD_MCT - Modified census which is memorizing for each pixel 2 bits and includes a tolerance to the pixel comparison MCT_MEAN_VARIATION - Implementation of a modified census transform which is also taking into account the variation to the mean of the window not just the center pixel *
star_census_transform
in a 9x9 kernel only certain positions are choosen
star_census_transform_1
single image version of star kernel
symetric_census_transform
The classical center symetric census A modified version of cs census which is comparing a pixel with its correspondent after the center *
symetric_census_transform_1
single version of census transform