pub struct LightGlueMatcher { /* private fields */ }Expand description
LightGlue feature matcher.
LightGlue is a CNN-based feature matcher, as described in Lindenberger23 . It takes keypoint locations and descriptors from two images and directly predicts match pairs. Unlike traditional matchers that compute descriptor distances, LightGlue uses attention mechanisms to produce confidence scores for each potential match pair.
The matcher extends DescriptorMatcher and supports the standard match(), knnMatch(), and radiusMatch() interfaces. Context (keypoints and image sizes) must be provided via setPairInfo() before matching.
Implementations
Sourceimpl LightGlueMatcher
impl LightGlueMatcher
Sourcepub fn create(
model_path: impl AsRef<OsStr>,
score_threshold: f32,
backend: i32,
target: i32,
) -> Result<Ptr<LightGlueMatcher>>
pub fn create( model_path: impl AsRef<OsStr>, score_threshold: f32, backend: i32, target: i32, ) -> Result<Ptr<LightGlueMatcher>>
Sourcepub fn create_def(
model_path: impl AsRef<OsStr>,
) -> Result<Ptr<LightGlueMatcher>>
pub fn create_def( model_path: impl AsRef<OsStr>, ) -> Result<Ptr<LightGlueMatcher>>
Creates LightGlueMatcher from a model file path.
Parameters
- modelPath: Path to the ONNX model file.
- scoreThreshold: Match confidence threshold.
- backend: DNN backend
- target: DNN target
Note
This alternative version of LightGlueMatcher::create function uses the following default values for its arguments:
- score_threshold: 0.0f
- backend: 0
- target: 0
Sourcepub fn create_from_memory(
model_data: &Vector<u8>,
score_threshold: f32,
backend: i32,
target: i32,
) -> Result<Ptr<LightGlueMatcher>>
pub fn create_from_memory( model_data: &Vector<u8>, score_threshold: f32, backend: i32, target: i32, ) -> Result<Ptr<LightGlueMatcher>>
Sourcepub fn create_from_memory_def(
model_data: &Vector<u8>,
) -> Result<Ptr<LightGlueMatcher>>
pub fn create_from_memory_def( model_data: &Vector<u8>, ) -> Result<Ptr<LightGlueMatcher>>
Creates LightGlueMatcher from in-memory model data.
Parameters
- modelData: Buffer containing the model data.
- scoreThreshold: Match confidence threshold.
- backend: DNN backend
- target: DNN target
Note
This alternative version of LightGlueMatcher::create_from_memory function uses the following default values for its arguments:
- score_threshold: 0.0f
- backend: 0
- target: 0