pub fn get_perspective_transform_slice_def(
src: [Point2f; 4],
dst: [Point2f; 4],
) -> Result<Mat>Expand description
Calculates a perspective transform from four pairs of the corresponding points.
The function calculates the matrix of a perspective transform so that:
where
Parameters
- src: Coordinates of quadrangle vertices in the source image.
- dst: Coordinates of the corresponding quadrangle vertices in the destination image.
- solveMethod: method passed to cv::solve (#DecompTypes)
See also
findHomography, warpPerspective, perspectiveTransform
Overloaded parameters
Note
This alternative version of get_perspective_transform_slice function uses the following default values for its arguments:
- solve_method: DECOMP_LU